@@ -1,5 +1,8 @@
 package Business::ID::NPWP;
 
+our $DATE = '2015-07-10'; # DATE
+our $VERSION = '0.06'; # VERSION
+
 use 5.010001;
 use warnings;
 use strict;
@@ -8,8 +11,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(parse_npwp);
 
-our $VERSION = '0.05'; # VERSION
-
 our %SPEC;
 
 sub _z { $_[0] > 9 ? $_[0]-9 : $_[0] }
@@ -67,7 +68,7 @@ sub parse_npwp {
 }
 
 1;
-# ABSTRACT: Validate Indonesian taxpayer registration number (NPWP)
+# ABSTRACT: Parse Indonesian taxpayer registration number (NPWP)
 
 __END__
 
@@ -77,11 +78,11 @@ __END__
 
 =head1 NAME
 
-Business::ID::NPWP - Validate Indonesian taxpayer registration number (NPWP)
+Business::ID::NPWP - Parse Indonesian taxpayer registration number (NPWP)
 
 =head1 VERSION
 
-This document describes version 0.05 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2014-08-16.
+This document describes version 0.06 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2015-07-10.
 
 =head1 SYNOPSIS
 
@@ -137,8 +138,6 @@ Input NPWP to be parsed.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -148,7 +147,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -156,7 +155,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Business-ID-NPWP>.
+Source repository is at L<https://github.com/perlancar/perl-Business-ID-NPWP>.
 
 =head1 BUGS
 
@@ -168,11 +167,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
